<?php

/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
/* (c) 2000 Fabio Molinari <fabio.m@mclink.it> */
/* (c) 2001 Andrew Stubbs <andrews@stusoft.com> */

$appoggio = return_star();

$t->set_var(array(

"Please_fill_out_this_contact_form" => "Sei pregato di riempire il seguente modulo; tieni presente che &egrave; necessario riempire tutti i campi contrassegnati con un asterisco (" . $appoggio . ").",
"First_and_Last_Name" => "Nome e Cognome<br>(o Ragione Sociale)",

));

?>
